Stan Math Library: stan/math/prim/arr/fun/promote_scalar_type.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

promote_scalar_type.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_ARR_FUN_PROMOTE_SCALAR_TYPE_HPP
2 #define STAN_MATH_PRIM_ARR_FUN_PROMOTE_SCALAR_TYPE_HPP
3
4 #include <stan/math/prim/scal/fun/promote_scalar_type.hpp>
5 #include <vector>
6
7 namespace stan {
8 namespace math {
9
18 template <typename T, typename S>
19 struct promote_scalar_type<T, std::vector<S> > {
23 typedef std::vector<typename promote_scalar_type<T, S>::type> type;
24 };
25
26 }
27 }
28 #endif
stan
Definition: log_sum_exp.hpp:8
std
Definition: std_numeric_limits.hpp:7
stan::math::promote_scalar_type
Template metaprogram to calculate a type for converting a convertible type.
Definition: promote_scalar_type.hpp:15
promote_scalar_type.hpp
stan::math::promote_scalar_type< T, std::vector< S > >::type
std::vector< typename promote_scalar_type< T, S >::type > type
The promoted type.
Definition: promote_scalar_type.hpp:23

[ Stan Home Page ] © 2011–2016, Stan Development Team.